@@ -77,7 +77,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = "0.01_3";
+our $VERSION = 0.01;
 
 require XSLoader;
 XSLoader::load('ISAL::Crypto', $VERSION);
@@ -141,18 +141,17 @@ registers calculations.
 
 Return hash reference with format C<< {"HAS_$FEATURE_NAME_UPPERCASE" => 1,} >>.
 For example:
-
-    {
-        HAS_SSE  => 1,
-        HAS_AVX  => 1,
-        HAS_AVX2 => 0,
-        HAS_AVX512   => 0,
-        HAS_AVX512F  => 0,
-        HAS_AVX512VL => 0,
-        HAS_AVX512BW => 0,
-        HAS_AVX512CD => 0,
-        HAS_AVX512DQ => 0,
-    }
+C<< {
+    HAS_SSE  => 1,
+    HAS_AVX  => 1,
+    HAS_AVX2 => 0,
+    HAS_AVX512   => 0,
+    HAS_AVX512F  => 0,
+    HAS_AVX512VL => 0,
+    HAS_AVX512BW => 0,
+    HAS_AVX512CD => 0,
+    HAS_AVX512DQ => 0,
+} >>
 
 =item ISAL::Crypto::get_cpu_features
 
@@ -322,7 +321,7 @@ To start benchmark run C<make bench> in console.
 
 =over 4
 
-=item Assembler: nasm v2.13 or better (suggested for building in AVX512 support).
+=item Assembler: nasm v2.11.01 or later (nasm v2.13 or better suggested for building in AVX512 support) or yasm version 1.2.0 or later.
 
 =item Compiler: gcc, clang or icc compiler.
 
@@ -346,7 +345,7 @@ To start benchmark run C<make bench> in console.
 
 =head1 AUTHOR
 
-Sergey Kaplun, E<lt>burii@cpan.orgE<gt>,
+Sergey Kaplun, E<lt>burii@cpan.org<gt>,
 
 =head1 ACKNOWLEDGEMENTS
 
